==> wp2-be-institutional-page-bs-1.2.0-20260123.101316-2-sources.jar: com/finconsgroup/itserr/marketplace/institutional_page/bs/util/Constants.java <==
package com.finconsgroup.itserr.marketplace.institutional_page.bs.util;

public class Constants {
    public static final String VALIDATION_ERROR_REQUIRED_FIELD = "Required field";
    public static final String VALIDATION_ERROR_FIELD_LENGTH = "Field length must be between {min} and {max}";
    public static final String VALIDATION_ERROR_FIELD_IP_COPYRIGHT_YEAR_PATTERN = "Year must be a 4-digit number between {min} and {max}";
    public static final String VALIDATION_ERROR_FIELD_IP_NAME_PATTERN = "Only letters, numbers, spaces, underscore (_) and dash (-) are allowed";
    public static final String VALIDATION_ERROR_FIELD_IP_CATEGORY_ALLOWED_VALUES = "Allowed values: 'tool', 'project'";
    public static final String VALIDATION_ERROR_FIELD_IP_PENDING_MODERATION_STATUS_ALLOWED_VALUES = "Allowed values: 'Pending', 'Rejected'";
    public static final String VALIDATION_ERROR_FIELD_IP_ASSOCIATIONS_ALLOWED_VALUES = "Allowed values: 'parent', 'wpLeads', 'contributors', 'childInstitutionalPages', 'paragraphs'";

    public static final int MAX_MEDIUM_TEXT_LENGTH = 255;
    public static final int MAX_SUPPORTED_OS_LENGTH = 800;
    public static final int MAX_LONG_TEXT_LENGTH = 8000;

    /**
     * Filter key used to identify the service in the message metadata.
     */
    public static final String SERVICE_FILTER_KEY = "service";
    /**
     * Filter value associated with the catalog service.
     */
    public static final String SERVICE_FILTER_VALUE = "institutional-page";

    private Constants() {
    }
}

==> wp2-be-institutional-page-bs-1.4.0-sources.jar: com/finconsgroup/itserr/marketplace/institutional_page/bs/util/Constants.java <==
package com.finconsgroup.itserr.marketplace.institutional_page.bs.util;

public class Constants {
    public static final String VALIDATION_ERROR_REQUIRED_FIELD = "Required field";
    public static final String VALIDATION_ERROR_FIELD_LENGTH = "Field length must be between {min} and {max}";
    public static final String VALIDATION_ERROR_FIELD_IP_COPYRIGHT_YEAR_PATTERN = "Year must be a 4-digit number between {min} and {max}";
    public static final String VALIDATION_ERROR_FIELD_IP_NAME_PATTERN = "Only letters, numbers, spaces, underscore (_) and dash (-) are allowed";
    public static final String VALIDATION_ERROR_FIELD_IP_CATEGORY_ALLOWED_VALUES = "Allowed values: 'tool', 'project'";
    public static final String VALIDATION_ERROR_FIELD_IP_PENDING_MODERATION_STATUS_ALLOWED_VALUES = "Allowed values: 'Pending', 'Rejected'";
    public static final String VALIDATION_ERROR_FIELD_IP_ASSOCIATIONS_ALLOWED_VALUES = "Allowed values: 'all', 'none', 'parentInstitutionalPage', 'wpLeads', 'members', 'childInstitutionalPages', 'paragraphs'";

    public static final int MAX_MEDIUM_TEXT_LENGTH = 255;
    public static final int MAX_SUPPORTED_OS_LENGTH = 800;
    public static final int MAX_LONG_TEXT_LENGTH = 8000;

    /**
     * Filter key used to identify the service in the message metadata.
     */
    public static final String SERVICE_FILTER_KEY = "service";
    /**
     * Filter value associated with the catalog service.
     */
    public static final String SERVICE_FILTER_VALUE = "institutional-page";

    private Constants() {
    }
}
